==> kdevplatform-1.6.0.tar.xz: kdevplatform-1.6.0/plugins/codeutils/kdevcodeutils.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=Collection of various utilities that increase productivity while programming.
Comment[bs]=Kolekcija raznih alata koji povećavaju produktivnost tokom programiranja.
Comment[ca]=Col·lecció de diverses utilitzats que augmenten la productivitat durant la programació.
Comment[ca@valencia]=Col·lecció de diverses utilitzats que augmenten la productivitat durant la programació.
Comment[da]=Samling af diverse værktøjer til at forøge produktiviteten når du programmerer.
Comment[de]=Sammlung verschiedener Werkzeuge, die die Produktivität während des Programmierens erhöhen.
Comment[el]=Συλλογή διάφορων βοηθητικών προγραμμάτων που αυξάνουν την παραγωγικότητα κατά τον προγραμματισμό
Comment[en_GB]=Collection of various utilities that increase productivity while programming.
Comment[es]=Colección de diversas utilidades que incrementan la productividad al programar.
Comment[et]=Mitmesugused tööriistad, mis suurendavad produktiivsust programmeerimisel.
Comment[fi]=Kokoelma sekalaisia työkaluja, jotka lisäävät ohjelmointisi tuottavuutta.
Comment[fr]=Collections de divers utilitaires conçus pour accroître la productivité tout en programmant.
Comment[gl]=Colección de varias utilidades que aumentan a produtividade durante a programación.
Comment[hu]=Különféle segédprogramok gyűjteménye, amelyek növelik a termelékenységet a programozás során.
Comment[it]=Raccolta di varie utilità che aumentano la produttività durante la programmazione.
Comment[kk]=Программалау өнімділігін аттыратын түрлі утилиталар жиыны.
Comment[nb]=En samling av ymse verktøy som øker produktiviteten under programmering.
Comment[nds]=Sammeln vun verscheden Hülpprogrammen för Leistentowass bi't Programmeren
Comment[nl]=Verzameling van hulpprogramma's die de productiviteit vergroot bij het programmeren
Comment[pl]=Kolekcja różnych narzędzi zwiększających produktywność podczas programowania.
Comment[pt]=Uma colecção de vários utilitários que aumentam a produtividade enquanto programa.
Comment[pt_BR]=Uma coleção de vários utilitários que aumentam a produtividade durante a programação.
Comment[ru]=Коллекция различных утилит, увеличивающих продуктивность процесса программирования.
Comment[sk]=Zbierka rôznych utilít, ktoré zvyšujú produktivitu počas programovania.
Comment[sl]=Zbirka raznih pripomočkov, ki povečajo učinkovitost med programiranjem.
Comment[sv]=Samling av diverse verktyg för att öka produktiviteten vid programmering.
Comment[tr]=Programlama sırasında verimliliği arttırmak için çeşitli yardımcı araçlardan oluşan bir koleksiyon.
Comment[ug]=پروگرامما ئىشلەش ئۈنۈمىنى يۇقىرى كۆتۈرۈشكە پايدىلىق بولغان ھەر خىل قوراللارنىڭ توپلىمى.
Comment[uk]=Збірка різноманітних допоміжних програм, яка підвищує продуктивність програмування.
Comment[x-test]=xxCollection of various utilities that increase productivity while programming.xx
Comment[zh_CN]=多种提升编程生产力的工具集合。
Comment[zh_TW]=各種可以增加寫程式效率的工具的收藏。
Name=Code Utilities
Name[bs]=Kodni alati
Name[ca]=Utilitats de codi
Name[ca@valencia]=Utilitats de codi
Name[da]=Kodeværktøjer
Name[de]=Quelltext-Werkzeuge
Name[el]=Βοηθητικά προγράμματα
Name[en_GB]=Code Utilities
Name[es]=Utilidades de código fuente
Name[et]=Kooditööriistad
Name[fi]=Koodityökalut
Name[fr]=Utilitaires de code
Name[gl]=Utilidades de código
Name[hu]=Kód segédprogramok
Name[it]=Utilità per il codice
Name[ja]=コードユーティリティ
Name[kk]=Код утилиталары
Name[nb]=Kodeverktøy
Name[nds]=Kode-Warktüüch
Name[nl]=Hulpmiddelen bij coderen
Name[pl]=Narzędzia kodu
Name[pt]=Utilitários de Código
Name[pt_BR]=Utilitários de Código
Name[ru]=Утилиты для работы с кодом
Name[sk]=Nástroje kódu
Name[sl]=Pripomočki za kodo
Name[sv]=Kodverktyg
Name[tr]=Kod Araçları
Name[ug]=كود قوراللىرى
Name[uk]=Допоміжні засоби
Name[x-test]=xxCode Utilitiesxx
Name[zh_CN]=代码工具
Name[zh_TW]=寫程式實用工具
GenericName=Code Utilities
GenericName[bs]=Kodni alati
GenericName[ca]=Utilitats de codi
GenericName[ca@valencia]=Utilitats de codi
GenericName[da]=Kodeværktøjer
GenericName[de]=Quelltext-Werkzeuge
GenericName[el]=Βοηθητικά προγράμματα
GenericName[en_GB]=Code Utilities
GenericName[es]=Utilidades de código fuente
GenericName[et]=Kooditööriistad
GenericName[fi]=Koodityökalut
GenericName[fr]=Utilitaires de code
GenericName[gl]=Utilidades de código
GenericName[hu]=Kód segédprogramok
GenericName[it]=Utilità per il codice
GenericName[ja]=コードユーティリティ
GenericName[kk]=Код утилиталары
GenericName[nb]=Kodeverktøy
GenericName[nds]=Kode-Warktüüch
GenericName[nl]=Hulpmiddelen bij coderen
GenericName[pl]=Narzędzia kodu
GenericName[pt]=Utilitários de Código
GenericName[pt_BR]=Utilitários de Código
GenericName[ru]=Утилиты для работы с кодом
GenericName[sk]=Nástroje kódu
GenericName[sl]=Pripomočki za kodo
GenericName[sv]=Kodverktyg
GenericName[tr]=Kod Araçları
GenericName[ug]=كود قوراللىرى
GenericName[uk]=Допоміжні засоби
GenericName[x-test]=xxCode Utilitiesxx
GenericName[zh_CN]=代码工具
GenericName[zh_TW]=寫程式實用工具
Icon=help-hint
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcodeutils
X-KDE-PluginInfo-Name=kdevcodeutils
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform_1.7.1.orig.tar.xz: kdevplatform-1.7.1/plugins/codeutils/kdevcodeutils.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=Collection of various utilities that increase productivity while programming.
Comment[bs]=Kolekcija raznih alata koji povećavaju produktivnost tokom programiranja.
Comment[ca]=Col·lecció de diverses utilitzats que augmenten la productivitat durant la programació.
Comment[ca@valencia]=Col·lecció de diverses utilitzats que augmenten la productivitat durant la programació.
Comment[da]=Samling af diverse værktøjer til at forøge produktiviteten når du programmerer.
Comment[de]=Sammlung verschiedener Werkzeuge, die die Produktivität während des Programmierens erhöhen.
Comment[el]=Συλλογή διάφορων βοηθητικών προγραμμάτων που αυξάνουν την παραγωγικότητα κατά τον προγραμματισμό
Comment[en_GB]=Collection of various utilities that increase productivity while programming.
Comment[es]=Colección de diversas utilidades que incrementan la productividad al programar.
Comment[et]=Mitmesugused tööriistad, mis suurendavad produktiivsust programmeerimisel.
Comment[fi]=Kokoelma sekalaisia työkaluja, jotka lisäävät ohjelmointisi tuottavuutta.
Comment[fr]=Collections de divers utilitaires conçus pour accroître la productivité tout en programmant.
Comment[gl]=Colección de varias utilidades que aumentan a produtividade durante a programación.
Comment[hu]=Különféle segédprogramok gyűjteménye, amelyek növelik a termelékenységet a programozás során.
Comment[it]=Raccolta di varie utilità che aumentano la produttività durante la programmazione.
Comment[kk]=Программалау өнімділігін аттыратын түрлі утилиталар жиыны.
Comment[nb]=En samling av ymse verktøy som øker produktiviteten under programmering.
Comment[nds]=Sammeln vun verscheden Hülpprogrammen för Leistentowass bi't Programmeren
Comment[nl]=Verzameling van hulpprogramma's die de productiviteit vergroot bij het programmeren.
Comment[pl]=Kolekcja różnych narzędzi zwiększających produktywność podczas programowania.
Comment[pt]=Uma colecção de vários utilitários que aumentam a produtividade enquanto programa.
Comment[pt_BR]=Uma coleção de vários utilitários que aumentam a produtividade durante a programação.
Comment[ru]=Коллекция различных утилит, увеличивающих продуктивность процесса программирования.
Comment[sk]=Zbierka rôznych utilít, ktoré zvyšujú produktivitu počas programovania.
Comment[sl]=Zbirka raznih pripomočkov, ki povečajo učinkovitost med programiranjem.
Comment[sv]=Samling av diverse verktyg för att öka produktiviteten vid programmering.
Comment[tr]=Programlama sırasında verimliliği arttırmak için çeşitli yardımcı araçlardan oluşan bir koleksiyon.
Comment[ug]=پروگرامما ئىشلەش ئۈنۈمىنى يۇقىرى كۆتۈرۈشكە پايدىلىق بولغان ھەر خىل قوراللارنىڭ توپلىمى.
Comment[uk]=Збірка різноманітних допоміжних програм, яка підвищує продуктивність програмування.
Comment[x-test]=xxCollection of various utilities that increase productivity while programming.xx
Comment[zh_CN]=多种提升编程生产力的工具集合。
Comment[zh_TW]=各種可以增加寫程式效率的工具的收藏。
Name=Code Utilities
Name[bs]=Kodni alati
Name[ca]=Utilitats de codi
Name[ca@valencia]=Utilitats de codi
Name[da]=Kodeværktøjer
Name[de]=Quelltext-Werkzeuge
Name[el]=Βοηθητικά προγράμματα
Name[en_GB]=Code Utilities
Name[es]=Utilidades de código fuente
Name[et]=Kooditööriistad
Name[fi]=Koodityökalut
Name[fr]=Utilitaires de code
Name[gl]=Utilidades de código
Name[hu]=Kód segédprogramok
Name[it]=Utilità per il codice
Name[ja]=コードユーティリティ
Name[kk]=Код утилиталары
Name[nb]=Kodeverktøy
Name[nds]=Kode-Warktüüch
Name[nl]=Hulpmiddelen bij coderen
Name[pl]=Narzędzia kodu
Name[pt]=Utilitários de Código
Name[pt_BR]=Utilitários de Código
Name[ru]=Утилиты для работы с кодом
Name[sk]=Nástroje kódu
Name[sl]=Pripomočki za kodo
Name[sv]=Kodverktyg
Name[tr]=Kod Araçları
Name[ug]=كود قوراللىرى
Name[uk]=Допоміжні засоби
Name[x-test]=xxCode Utilitiesxx
Name[zh_CN]=代码工具
Name[zh_TW]=寫程式實用工具
GenericName=Code Utilities
GenericName[bs]=Kodni alati
GenericName[ca]=Utilitats de codi
GenericName[ca@valencia]=Utilitats de codi
GenericName[da]=Kodeværktøjer
GenericName[de]=Quelltext-Werkzeuge
GenericName[el]=Βοηθητικά προγράμματα
GenericName[en_GB]=Code Utilities
GenericName[es]=Utilidades de código fuente
GenericName[et]=Kooditööriistad
GenericName[fi]=Koodityökalut
GenericName[fr]=Utilitaires de code
GenericName[gl]=Utilidades de código
GenericName[hu]=Kód segédprogramok
GenericName[it]=Utilità per il codice
GenericName[ja]=コードユーティリティ
GenericName[kk]=Код утилиталары
GenericName[nb]=Kodeverktøy
GenericName[nds]=Kode-Warktüüch
GenericName[nl]=Hulpmiddelen bij coderen
GenericName[pl]=Narzędzia kodu
GenericName[pt]=Utilitários de Código
GenericName[pt_BR]=Utilitários de Código
GenericName[ru]=Утилиты для работы с кодом
GenericName[sk]=Nástroje kódu
GenericName[sl]=Pripomočki za kodo
GenericName[sv]=Kodverktyg
GenericName[tr]=Kod Araçları
GenericName[ug]=كود قوراللىرى
GenericName[uk]=Допоміжні засоби
GenericName[x-test]=xxCode Utilitiesxx
GenericName[zh_CN]=代码工具
GenericName[zh_TW]=寫程式實用工具
Icon=help-hint
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevcodeutils
X-KDE-PluginInfo-Name=kdevcodeutils
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
